gen2Z <-
function (gen) 
{
    return(genZ2Z(gen2genZ(gen)))
}
